extensions [csv]
breed[persons person]

globals [group_grants group_success interaction_LOG]

persons-own[
  person_type                    ; Agent type A/B, option to setup different endowment
  budget                         ; Agent's budget based on GUI setup
  group_id                       ; Group ID where agent belongs
  origin_group                   ; ID of agent's origin group
  grant                          ; Agent's contribution
  first_grant                    ; Agent's contribution in first round
  reward                         ; Agent's reward after one round
  decision_log                   ; Log of each decision of agent
  investigation_fee              ; Fee for the investigation
  punishment_decision            ; Decision weather to punish or not
  punishment                     ; Punishment amount

  ; RothErev learning algorithm
  re_VECTOR_grant                ; Learning vector with propensity and probability for each strategy - contribution size
  re_VECTOR_punish               ; Learning vector with propensity and probability for each strategy - punishment
  ]

; Setup declaration
to setup
  clear-all
  reset-ticks
  prepareListLogs
  set log-filename remove ":" remove " " word date-and-time ".csv"
  ifelse(group_size MOD 2 = 0 )[
    createPersons
  ][
    show "velkost skupiny musi byt parne cislo"
  ]
end

; GO declaration
to go
  decide
  evaluateGrants
  learn
  tick
  plotProbability
end

; Method for creating agents
to createPersons
  let i 0
  let angle 0
  let r 15
  let agents_count groups_count * group_size
  let step 360 / agents_count
  let g_id 0
  while[i < agents_count][
    if (i MOD group_size = 0 )[
      set g_id g_id + 1
    ]
    createPerson "A" (0 + r * cos(angle)) (0 + r * sin(angle)) g_id
    set angle angle + step
    createPerson "B" (0 + r * cos(angle)) (0 + r * sin(angle)) g_id
    set angle angle + step
    set i i + 2
  ]
end

; Decision method setup based on method setup in GUI
to decide
if(decision-method = "rothErev")[
    ask persons [
      set grant rothErevDecide re_VECTOR_grant                ; Decision regarding contribution size
      set punishment_decision rothErevDecide re_VECTOR_punish ; Decision wheather to punish or not
    ]
  ]
end

; Method for reward calculation
to evaluateGrants
  let g_id 1
  let needed_grant_per_person grant-threshold / group_size
  while [g_id <= groups_count][
    let total_grant sum [grant] of persons with [group_id = g_id]
    let punish_probab 1
    let police_fee punish_probab * investigation-fee
    logGroupGrant g_id total_grant
    let grant_succesfull? total_grant >= grant-threshold
    logGroupSuccess g_id grant_succesfull?
    ask persons with [group_id = g_id] [
      if( first_grant = -555 )[
        set first_grant grant
        set label word person_type (word " | " first_grant)
      ]
      ifelse (grant_succesfull?)
      [
      set reward ( budget - grant + (multiplicator * total_grant / group_size) )
        set color green
      ][
        set color red
        ifelse (penalization-type = "fixed penalization")[
          set reward ( budget - penalization)
        ][
          set reward budget - grant
        ]
      ]
      set investigation_fee police_fee
      set reward (reward - investigation_fee)
      ifelse(grant < needed_grant_per_person)[
        let dice random-float 1
        ifelse(dice <= punish_probab)[
          set punishment (needed_grant_per_person - grant)
          set reward reward - punishment
        ][
          set punishment 0
        ]
      ][set punishment 0]
      if(reward < 0 )[set reward 0]
      logActivity ticks who group_id origin_group person_type budget grant total_grant grant_succesfull? reward investigation_fee punishment_decision punishment e_param r_param multiplicator
    ]
    set g_id g_id + 1
  ]
end

; Learning mechanism based on decision method for contribution size and punishment decision
to learn
  if(decision-method = "rothErev")[
    ask persons[
      set re_VECTOR_grant rothErevLearn re_VECTOR_grant grant reward
      set re_VECTOR_punish rothErevLearn re_VECTOR_punish punishment_decision reward
    ]
  ]
end

;Decision method based on Roth-Erev learning algorithm
to-report rothErevDecide [VECTOR]
  let vect_length (length (re_VECTOR_grant)) / 3
  let dice random-float 1
  let current_poss 0
  let chosen_value -5
  let i 0
  while [i < vect_length][
    set current_poss current_poss + (item ((i * 3) + 2) VECTOR)
    if (dice <= current_poss)[
      set chosen_value (item (i * 3) VECTOR)
      report chosen_value
    ]
    set i i + 1
  ]
  if (chosen_value = -5)[
    error "Error - could not decide"
  ]
end

;Learning method based on Roth-Erev learning algorithm
to-report rothErevLearn [VECTOR itm rwrd]
  let temp VECTOR
  let value rwrd
  let min_profit 0
  let max_profit 100
  let new_income (value - min_profit) / (max_profit - min_profit)
  if(new_income < 0 or new_income > 1 )[show word "Error in normalized profit: " new_income]
  let j 0
  let strategiesCount length(temp) / 3
  while [j < strategiesCount ][
    let q_j item ((j * 3) + 1) temp
    let E_j 0
    ifelse( itm = item (j * 3)  temp)
      [
        set E_j new_income * (1 - e_param )
      ][
        set E_j new_income * (e_param / strategiesCount)
    ]
    set q_j (1 - r_param) * q_j + E_j
    set temp replace-item ((j * 3) + 1) temp q_j
    set j j + 1
  ]
  ; RothErev probability update
  set j 0
  let denominator 0
  while [j < strategiesCount][
    let strategyJ_payoff item ((j * 3) + 1) temp
    set denominator denominator + strategyJ_payoff
    set j j + 1
  ]
  let i 0
  while [i < strategiesCount][
    let strategyI_payoff item ((i * 3) + 1) temp
    if (strategyI_payoff < 0)[show word "total payoff of strategy is lower than 0  ||vector:"  temp]
    let probab (strategyI_payoff / denominator)
    set temp replace-item ((i * 3) + 2) temp probab
    set i i + 1
  ]
  report temp
end

; Method for generating agents
to createPerson [p_type x y g_id]
  create-persons 1[
    set person_type p_type
    set group_id g_id
    set origin_group g_id
    set xcor x
    set ycor y
    set size 2
    set color yellow
    set first_grant -555
    set re_VECTOR_punish [0 0.5 0.5 1 0.5 0.5]
    if(person_type = "A")[
      set shape getShape g_id
      set budget budget-A
      set re_VECTOR_grant generateRothErevVector budget strategy-step
    ]
    if(person_type = "B")[
      set shape getShape g_id
      set budget budget-B
      set re_VECTOR_grant generateRothErevVector budget strategy-step
    ]
    set label word person_type " |"
  ]
end

; Method for agents switching groups
to mixGroups
  let group_index 1
  let agents_count groups_count * group_size
  let g_id 1
  ask persons with [person_type = "A"] [
    if ( g_id > groups_count)[set g_id 1]
    set group_id g_id
    set g_id g_id + 1
  ]
  ask persons with [person_type = "B"] [
    if ( g_id > groups_count)[set g_id 1]
    set group_id g_id
    set g_id g_id + 1
  ]
end

; Agents coloring
to paintGroups
  let i 1
  let p_color one-of base-colors
  while[i <= groups_count][
    set p_color one-of base-colors
    ask persons with [group_id = i][
      set color p_color
      set label group_id

    ]
    set i i + 1
  ]
end

;Setup shape for graphs
to-report getShape [index]
  report item index ["line" "circle" "flag" "face happy" "square" "fish" "triangle" "box" "flag" "house" "cow" "circle 2" "leaf" "pentagram" "arrow" "wolf" "tree" "x"]
end

;Setup colors for graphs
to-report getColor [index]
  let cols [red green blue orange gray yellow pink brown sky lime magenta ]
  ifelse(index >= length cols)[report black][
    report item index cols
  ]
end

;Initialization of Roth-Erev vector for each agent
to-report generateRothErevVector [ maximum step ]
  let no_of_strat (maximum / step) + 1
  let value 0
  let density 1 / no_of_strat
  let probab density
  let vector []
  repeat no_of_strat[
    set vector lput value vector
    set vector lput density vector
    set vector lput probab vector
    set value value + step
  ]
  report vector
end

;Plotting for Roth-Erev learning algorithm for specific agent
to plotProbability
  carefully[
  ask person re-person-id[
    set-current-plot "Learning of person with id re-person-id"
    clear-plot
    set-plot-pen-mode 1
    let i 0
      let strategies_count (length re_VECTOR_grant / 3)
    while [i < strategies_count][
      plotxy (item (i * 3) re_VECTOR_grant) (item ((i * 3) + 2) re_VECTOR_grant)
      set i i + 1
    ]
  ]
][set-current-plot "Learning of person with id re-person-id"
    clear-plot]
end

; ================================================= Logging ==================================================================
to prepareListLogs
  set interaction_LOG []
  logActivity "time" "person_id" "group_id" "origin_group" "person_type" "budget" "grant" "group_grant" "succesfull" "reward"  "investigation_fee" "punishment_decision" "punishment"  "e_parameter" "r_parameter" "multiplicator"
  set group_grants  []
  repeat groups_count + 1 [
    set group_grants lput 0 group_grants
  ]
  set group_success []
  let temp [ 0 0]
  repeat groups_count + 1 [
    set group_success lput temp group_success
  ]
end

;Reporter for logging value of group grants
to logGroupGrant[id value]
  set group_grants replace-item id group_grants value
end

;Reporter for logging in nested list a number of groups in provision or non-provision state
to logGroupSuccess [id boolean]
  let temp item id group_success
  ifelse(boolean = true)[
    let succ item 0 temp + 1
    set temp replace-item 0 temp succ
  ][
    let unsucc item 1 temp + 1
    set temp replace-item 1 temp unsucc
  ]
  set group_success replace-item id group_success temp
end

;Reporter for logging statistics for given round
to logActivity [time id g_id o_group p_type bdgt grnt totalGrant succes? rwrd invstig_fee pnshmnt_dcsn pnshmnt e_parameter r_parameter multip]
  let row (list time id g_id o_group p_type bdgt grnt totalGrant succes? rwrd  invstig_fee pnshmnt_dcsn pnshmnt e_parameter r_parameter multip)
  set interaction_LOG lput row interaction_LOG
end

; Reporter for exporting logs to csv
to logToFileWriter_Write
  csv:to-file log-filename interaction_LOG
end
@#$#@#$#@
GRAPHICS-WINDOW
202
10
639
448
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
30.0

INPUTBOX
4
76
87
136
budget-A
30.0
1
0
Number

INPUTBOX
4
135
87
195
budget-B
30.0
1
0
Number

BUTTON
96
75
182
108
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
4
15
89
75
groups_count
5.0
1
0
Number

INPUTBOX
89
15
188
75
group_size
4.0
1
0
Number

CHOOSER
8
655
146
700
decision-method
decision-method
"rothErev"
0

INPUTBOX
5
279
94
339
grant-threshold
60.0
1
0
Number

INPUTBOX
92
279
184
339
penalization
5.0
1
0
Number

INPUTBOX
80
478
141
538
e_param
0.05
1
0
Number

INPUTBOX
140
478
198
538
r_param
0.05
1
0
Number

BUTTON
96
140
183
175
go-infinite
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

PLOT
662
11
992
221
Mean grant of a person
time
grant
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"grant" 1.0 0 -16777216 true "" "carefully [plot mean [grant] of persons][]"
"limit" 1.0 0 -2674135 true "" "plot grant-threshold / group_size"

PLOT
991
11
1361
221
Grants By Groups
money
time
0.0
10.0
0.0
10.0
true
true
"" "carefully[\nlet id 1\nwhile[id <= groups_count ][\n    create-temporary-plot-pen (word id)\n        set-plot-pen-color getColor id\n    plotxy ticks (item id group_grants)\n  set id id + 1\n ]][]"
PENS
"limit" 1.0 0 -2674135 true "" "plot grant-threshold"

INPUTBOX
664
236
781
296
group_identificator
1.0
1
0
Number

PLOT
664
295
1029
475
Grants of group with group_identificator
time
grant
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"grant" 1.0 0 -16777216 true "" "carefully[ plot item group_identificator group_grants][]"
"limit" 1.0 0 -2674135 true "" "plot grant-threshold"

PLOT
1028
294
1365
475
Grant of persons in group (group_identificator)
time
grant
0.0
10.0
0.0
10.0
true
true
"" "carefully[\nforeach  sort-on [who] persons with [group_id = group_identificator] \n  [\n  the-turtle -> ask the-turtle [\n    create-temporary-plot-pen (word who)\n    set-plot-pen-color getColor who\n    plotxy ticks grant\n  ]]\n][]"
PENS

INPUTBOX
5
478
81
538
strategy-step
5.0
1
0
Number

PLOT
202
447
640
674
Success of groups
time
% success
0.0
10.0
0.0
100.0
true
true
"" "carefully[\n\nlet id 1\nwhile[id <= groups_count ][\n    let temp item id group_success\n    let summ sum temp \n    let succ_ratio ((item 0 temp) / summ) * 100\n    create-temporary-plot-pen (word id)\n    set-plot-pen-color getColor id\n    plotxy ticks succ_ratio\n  set id id + 1\n ]][]"
PENS

INPUTBOX
1
562
200
622
log-filename
062204.678PM06-Jun-2020.csv
1
0
String

BUTTON
1
616
200
649
exportLog
logToFileWriter_Write
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
96
107
182
140
go-once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

TEXTBOX
8
463
158
481
Roth-Erev settings
11
0.0
1

TEXTBOX
9
547
159
565
Interaction log\n
11
0.0
1

CHOOSER
6
405
182
450
penalization-type
penalization-type
"fixed penalization" "loose whole grant"
1

INPUTBOX
668
490
770
550
re-person-id
1.0
1
0
Number

PLOT
770
490
1366
683
Learning of person with id re-person-id
grant value
probability
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

INPUTBOX
4
194
88
254
multiplicator
2.0
1
0
Number

INPUTBOX
97
177
185
237
X-times
5000.0
1
0
Number

BUTTON
96
236
186
269
go-X-times
repeat X-times [go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

INPUTBOX
5
338
95
398
investigation-fee
10.0
1
0
Number

PLOT
1360
10
1709
221
Votes for investigation
time
%
0.0
10.0
0.0
100.0
true
true
"" "carefully[\nlet id 1\nwhile[id <= groups_count ][\n    create-temporary-plot-pen (word id)\n        set-plot-pen-color getColor id\n    plotxy ticks 100 * (sum [punishment_decision] of persons with [group_id = id] / group_size)\n  set id id + 1\n ]][]"
PENS

@#$#@#$#@
## DOCUMENTATION

This is a cooperation model of threshold public goods games. In each round, all agents are granted a budget of size set in GUI. Then they decide on how much they contribute to public goods and how much they keep. Public goods are provided only if the sum of contributions meets or exceeds the threshold defined in the GUI. After each round agents evaluate their strategy and payoff from this strategy.

![Diagram](diagram.jpg)


### GUI Parameters:

#### General settings

**Groups count** -- defines number of separate groups per simulation
**Group size** -- number of players in each group per simulation
**Budget A and Budget B** -- agents are divided into two parts (A and B) for each group, for which different budget can be assigned
**Multiplicator** -- in a case of provision, how much increase a vule of contributions
**X-times** -- number of rounds per simulation
**Grant threshold** -- minimum amount of total contributions needed in order to provide public good
**Penalization** -- penalization fee in a case that public good is not provided and penalization type is set to fixed penalization
**Penalization type** -- implemented two types of penalization for case when sum of contributions are lower than **Grant thresold**:
lose whole grant or fixed penalization
**Decision method** -- learning mechanizm for agents on how to decide level of contribution
**Log filename** -- name of the log file with simulation results

#### Roth-Erev parameters

**Strategy step** -- agent strategies are defined by dividing agent budget with strategy step number and adding no contribution (i.e. contribution of size zero) 
**e parameter** -- experimentation parameter influences probability for trying other than optimal strategy
**r parameter** -- recency parameter influences how are previous experiences taken into consideration


@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
